@@ -26,8 +26,8 @@ async fn main() {
             // Box::new(CookieExtractor::new("jwt_token")),
         ])
         .with_response_error(false);
-    tracing::info!("Listening on http://127.0.0.1:7878");
-    Server::new(TcpListener::bind("127.0.0.1:7878"))
+    tracing::info!("Listening on http://0.0.0.0:7878");
+    Server::new(TcpListener::bind("0.0.0.0:7878"))
         .serve(Router::with_hoop(auth_handler).handle(index))
         .await;
 }
@@ -66,7 +66,7 @@ async fn index(req: &mut Request, depot: &mut Depot, res: &mut Response) -> anyh
                 res.render(Text::Html(LOGIN_HTML));
             }
             JwtAuthState::Forbidden => {
-                res.set_http_error(Forbidden());
+                res.set_status_error(Forbidden());
             }
         }
     }
