@@ -25,12 +25,12 @@ async fn main() {
     let router = Router::new()
         .handle(index)
         .push(Router::with_path("chat").handle(user_connected));
-    tracing::info!("Listening on http://127.0.0.1:7878");
-    Server::new(TcpListener::bind("127.0.0.1:7878")).serve(router).await;
+    tracing::info!("Listening on http://0.0.0.0:7878");
+    Server::new(TcpListener::bind("0.0.0.0:7878")).serve(router).await;
 }
 
 #[fn_handler]
-async fn user_connected(req: &mut Request, res: &mut Response) -> Result<(), HttpError> {
+async fn user_connected(req: &mut Request, res: &mut Response) -> Result<(), StatusError> {
     let fut = WsHandler::new().handle(req, res)?;
     let fut = async move {
         if let Some(ws) = fut.await {
